# https://datapacket.dl.sourceforge.net/project/openbabel/openbabel/2.4.1/openbabel-2.4.1.tar.gz
%define major 5
%define libname %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

Name:           openbabel
Version:        2.4.1
Release:        %mkrel 3
Summary:        Chemistry software file format converter

License:        GPLv2+
Group:          Sciences/Chemistry
URL:            http://openbabel.sourceforge.net/
Source:         %{name}-%{version}.tar.xz
Patch1:         %{name}-perl.patch
Patch4:         openbabel-plugindir.patch
Patch6:         openbabel-noswig-rubymethod.patch
Patch7:         openbabel-ruby19-vendorarch.patch
Patch8:         openbabel-disable-tests.patch
Patch9:         openbabel-narrowing-conversion.patch

BuildRequires:  doxygen
BuildRequires:  ImageMagick
BuildRequires:  %{_lib}eigen3-devel
BuildRequires:  %{_lib}wxgtku2.8-devel
BuildRequires:  libtool
BuildRequires:  cmake
BuildRequires:  libxml2-devel
BuildRequires:  perl(ExtUtils::MakeMaker)
BuildRequires:  python-devel
BuildRequires:  python3-devel
#BuildRequires:  ruby-devel
BuildRequires:  swig

Requires: %{libname} = %{version}

%description
Open Babel is a project designed to pick up where Babel left off,
as a cross-platform program and library designed to interconvert
between many file formats used in molecular modeling and computational
chemistry.

%package	-n %{libname}
Summary:        Shared libraries of %{name}
Group:          System/Libraries
Provides:	%{name} = %{version}-%{release}
Obsoletes:	libopenbabel2

%description	-n %{libname}
Open Babel is a project designed to pick up where Babel left off,
as a cross-platform program and library designed to interconvert
between many file formats used in molecular modeling and computational
chemistry.

This package contains shared libraries of %{name}.

%package	-n %{develname}
Summary:        Development files of %{name}
Group:          Development/Libraries
Requires:	%{libname} = %{version}
Provides:       %{name}-devel = %{version}-%{release}
Obsoletes:       %mklibname %{name} 2 -d
Obsoletes:       %mklibname %{name} 3 -d

%description	-n %{develname}
Open Babel is a project designed to pick up where Babel left off,
as a cross-platform program and library designed to interconvert
between many file formats used in molecular modeling and computational
chemistry.

This package includes the header files and other development
related files necessary for developing or compiling programs
using the %{name} library.

%package -n ruby-%{name}
Summary:    Ruby wrapper for the Open Babel library
Group:      Development/Libraries
Requires:   ruby
Requires:   %{name} = %{version}-%{release}

%description -n ruby-%{name}
Ruby wrapper for the Open Babel library.

%package -n python-%{name}
Group:      Development/Python
Summary:    Python wrapper for the Open Babel library
Requires:   %{name} = %{version}-%{release}
Provides:   %{name}-python = %{version}-%{release}

%description -n python-%{name}
Python wrapper for the Open Babel library.

%package -n python3-%{name}
Group:      Development/Python
Summary:    Python wrapper for the Open Babel library
Requires:   %{name} = %{version}-%{release}
Provides:   %{name}-python3 = %{version}-%{release}

%description -n python3-%{name}
Python wrapper for the Open Babel library.

%prep
%setup -q
%apply_patches

# Remove duplicate html files
pushd doc
for man in *.1; do
 html=`basename $man .1`.html
 if [ -f $html ]; then
   rm $html
 fi
done
popd

mkdir python3
for f in *; do
 if [ "$f" != "python3" ]; then
   cp -a $f python3/
 fi
done

%build
%cmake \
  -DENABLE_TESTS:BOOL=OFF \
  -DBUILD_GUI:BOOL=ON \
  -DENABLE_VERSIONED_FORMATS=false \
  -DCMAKE_SKIP_RPATH:BOOL=ON \
  -DPYTHON_BINDINGS:BOOL=ON \
  -DPYTHON_EXECUTABLE=%{__python2} \
  -DRUBY_BINDINGS:BOOL=ON \
  -DOPENBABEL_USE_SYSTEM_INCHI=OFF
%make_build

BUILD_DIR=$PWD
pushd ../python3
%cmake \
  -DENABLE_TESTS:BOOL=OFF \
  -DBUILD_GUI:BOOL=ON \
  -DENABLE_VERSIONED_FORMATS=false \
  -DCMAKE_SKIP_RPATH:BOOL=ON \
  -DPYTHON_BINDINGS:BOOL=ON \
  -DPYTHON_EXECUTABLE=%{__python3} \
  -DRUBY_BINDINGS:BOOL=ON \
  -DOPENBABEL_USE_SYSTEM_INCHI=OFF
%make_build bindings_python
popd

%install
rm -rf %{buildroot}
touch scripts/CMakeLists.txt
%makeinstall_std -C build

pushd python3
export DESTDIR=%{buildroot}
%cmake -DCOMPONENT=bindings_python -P cmake_install.cmake
popd

rm %{buildroot}%{_libdir}/cmake/openbabel2/*.cmake

# menu-entry
mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=OpenBabel
GenericName=Molecule Format Converter
Comment=Convert between many known molecule data formats
Exec=obgui
Icon=babel
Terminal=false
Type=Application
StartupNotify=true
Categories=Science;X-MandrivaLinux-MoreApplications-Sciences
EOF
convert src/GUI/babel.xpm -transparent white babel.png
install -Dpm644 babel.png $RPM_BUILD_ROOT%{_datadir}/pixmaps/babel.png

mkdir -p %{buildroot}%{_libdir}/ruby
# mv %{buildroot}/usr/local/lib64/ruby/site_ruby/openbabel.so %{buildroot}%{_libdir}/ruby

%files
%defattr(-,root,root)
%doc AUTHORS COPYING *.md
%doc doc/*.html doc/diox* doc/README*
%{_bindir}/*
%{_mandir}/man?/*
%{_datadir}/%{name}
%{_libdir}/%{name}/*.so
%{_datadir}/pixmaps/babel.png
%{_datadir}/applications/%{name}.desktop

%files -n %{libname}
%defattr(-,root,root)
%{_libdir}/lib*.so.%{major}*
%{_libdir}/libinchi.so.0
%{_libdir}/libinchi.so.0.4.1

%files -n %{develname}
%defattr(-,root,root)
%{_includedir}/%name-2.0
%{_includedir}/inchi/inchi_api.h
%{_libdir}/pkgconfig/*.pc
%{_libdir}/lib*.so
# %%{_libdir}/cmake/openbabel2

%files -n ruby-%{name}
%defattr(-,root,root)
#%{_libdir}/ruby

%files -n python-%{name}
%defattr(-,root,root)
%{python2_sitearch}/*

%files -n python3-%{name}
%defattr(-,root,root)
%{python3_sitearch}/*

%changelog
* Tue Mar 31 2020 tex - 2.4.1-3pclos2020
- rebuild against updates

* Thu Jan 31 2019 tex - 2.4.1-2pclos2019
- rebuild against updates

* Wed Apr 18 2018 marcin82 <fixxer1982 at gmail.com> 2.4.1-1pclos2018
- update, added patches from Fedora
- built python3 bindings

* Mon Jun 22 2015 bb <bb> 2.3.2-3pclos2015
- rebuild for updated wxgtk2.8

* Wed Jan 23 2013 MBantz <martin dot bantz at gmail dot com> 2.3.2-2
- Move libs and other to lib64 in 64 bit
- Rather large edit of spec

* Sun Jan 06 2013 Ken <lxgator at gmail dot com> 2.3.2-3pclos2012
- 2.3.2
